diff a/src/java.base/share/classes/java/lang/ref/WeakReference.java b/src/java.base/share/classes/java/lang/ref/WeakReference.java
--- a/src/java.base/share/classes/java/lang/ref/WeakReference.java
+++ b/src/java.base/share/classes/java/lang/ref/WeakReference.java
@@ -24,14 +24,18 @@
  */
 
 package java.lang.ref;
 
 
+import java.util.Objects;
+
 /**
  * Weak reference objects, which do not prevent their referents from being
  * made finalizable, finalized, and then reclaimed.  Weak references are most
  * often used to implement canonicalizing mappings.
+ * <p>
+ * The referent must be an {@linkplain Objects#hasIdentity(Object) identity object}.
  *
  * <p> Suppose that the garbage collector determines at a certain point in time
  * that an object is <a href="package-summary.html#reachability">weakly
  * reachable</a>.  At that time it will atomically clear all weak references to
  * that object and all weak references to any other weakly-reachable objects
@@ -51,10 +55,12 @@
     /**
      * Creates a new weak reference that refers to the given object.  The new
      * reference is not registered with any queue.
      *
      * @param referent object the new weak reference will refer to
+     * @throws IdentityException if the referent is not an
+     *         {@link java.util.Objects#hasIdentity(Object) identity object}
      */
     public WeakReference(T referent) {
         super(referent);
     }
 
@@ -63,10 +69,12 @@
      * registered with the given queue.
      *
      * @param referent object the new weak reference will refer to
      * @param q the queue with which the reference is to be registered,
      *          or {@code null} if registration is not required
+     * @throws IdentityException if the referent is not an
+     *         {@link java.util.Objects#hasIdentity(Object) identity object}
      */
     public WeakReference(T referent, ReferenceQueue<? super T> q) {
         super(referent, q);
     }
 
